@@ -70,10 +70,5 @@
 #define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
-#define QT_COMPILER_SUPPORTS_NEON 1
-#define QT_COMPILER_SUPPORTS_CRC32 1
-#define QT_COMPILER_SUPPORTS_CRYPTO 1
-#define QT_COMPILER_SUPPORTS_AES 1
-#define QT_COMPILER_SUPPORTS_SVE 1
 #define QT_LINKED_OPENSSL
 #define QT_GUI_TEST 1
